@@ -4,7 +4,8 @@
  * SPDX-FileCopyrightText: 2008 Valentin Rusu kde at rusu.info
  * SPDX-FileCopyrightText: 2018-2020 Michael Reeves reeves.87@gmail.com
  * SPDX-License-Identifier: GPL-2.0-or-later
-*/
+ */
+// clang-format on
 
 #ifndef GUIUTILS_H
 #define GUIUTILS_H
@@ -23,7 +24,7 @@ namespace GuiUtils {
        KActionCollection* ac,
        const QString& actionName)
    {
-       Q_ASSERT(ac != nullptr);
+       assert(ac != nullptr);
        QAction* theAction;
 
        theAction = ac->addAction(actionName);
@@ -39,7 +40,7 @@ namespace GuiUtils {
                    const Func slot,
                    KActionCollection* ac,
                    const QString &actionName)    {
-      Q_ASSERT( ac != nullptr );
+      assert( ac != nullptr );
       KToggleAction* theAction = new KToggleAction(ac);
       ac->addAction( actionName, theAction );
       theAction->setText( text );
@@ -128,7 +129,7 @@ namespace GuiUtils {
        KActionCollection* ac,
        const QString& actionName)
    {
-       Q_ASSERT(ac != nullptr);
+       assert(ac != nullptr);
        QAction* theAction;
 
        theAction = ac->addAction(actionName);
@@ -142,7 +143,7 @@ namespace GuiUtils {
                    const QString& text,
                    KActionCollection* ac,
                    const QString &actionName)    {
-      Q_ASSERT( ac != nullptr );
+      assert( ac != nullptr );
       KToggleAction* theAction = new KToggleAction(ac);
       ac->addAction( actionName, theAction );
       theAction->setText( text );
