@@ -143,8 +143,10 @@ class KDiff3App: public QMainWindow
     /** read general Options again and initialize all variables like the recent file list */
     void readOptions(KSharedConfigPtr);
 
-    // Finish initialisation (virtual, so that it can be called from the shell too.)
-    virtual void completeInit(const QString& fn1 = QString(), const QString& fn2 = QString(), const QString& fn3 = QString());
+    // Finish initialisation
+    void completeInit(const QString& fn1 = QString(), const QString& fn2 = QString(), const QString& fn3 = QString());
+    //Restore goementry and showMainWindow
+    void showMainWindow();
 
     /** queryClose is called by KMainWindow on each closeEvent of a window. Against the
      * default implementation (only returns true), this calles saveModified() on the document object to ask if the document shall
@@ -335,6 +337,7 @@ public Q_SLOTS:
     void keyPressEvent(QKeyEvent* event) override;
     void resizeEvent(QResizeEvent*) override;
 
+    bool doFileCompare();
     bool doDirectoryCompare(const bool bCreateNewInstance);
     void improveFilenames();
 
@@ -364,7 +367,7 @@ public Q_SLOTS:
     QPointer<QAction> editPaste;
     QPointer<QAction> editSelectAll;
     KToggleAction* viewToolBar = nullptr;
-    KToggleAction* viewStatusBar;
+    KToggleAction* viewStatusBar = nullptr;
 
     QPointer<QShortcut> mEscapeAction;
     ////////////////////////////////////////////////////////////////////////
@@ -382,36 +385,36 @@ public Q_SLOTS:
     QPointer<QAction> mGoPrevDelta;
     QPointer<QAction> mGoNextDelta;
     QPointer<QAction> mGotoLine;
-    KToggleAction* chooseA;
-    KToggleAction* chooseB;
-    KToggleAction* chooseC;
-    KToggleAction* autoAdvance;
-    KToggleAction* wordWrap;
+    KToggleAction* chooseA = nullptr;
+    KToggleAction* chooseB = nullptr;
+    KToggleAction* chooseC = nullptr;
+    KToggleAction* autoAdvance = nullptr;
+    KToggleAction* wordWrap = nullptr;
     QPointer<QAction> splitDiff;
     QPointer<QAction> joinDiffs;
     QPointer<QAction> addManualDiffHelp;
     QPointer<QAction> clearManualDiffHelpList;
-    KToggleAction* showWhiteSpaceCharacters;
-    KToggleAction* showWhiteSpace;
-    KToggleAction* showLineNumbers;
+    KToggleAction* showWhiteSpaceCharacters = nullptr;
+    KToggleAction* showWhiteSpace = nullptr;
+    KToggleAction* showLineNumbers = nullptr;
     QPointer<QAction> mAutoSolve;
     QPointer<QAction> mUnsolve;
     QPointer<QAction> mMergeHistory;
     QPointer<QAction> mergeRegExp;
-    KToggleAction* showWindowA;
-    KToggleAction* showWindowB;
-    KToggleAction* showWindowC;
+    KToggleAction* showWindowA = nullptr;
+    KToggleAction* showWindowB = nullptr;
+    KToggleAction* showWindowC = nullptr;
     QPointer<QAction> winFocusNext;
     QPointer<QAction> winFocusPrev;
     QPointer<QAction> winToggleSplitOrientation;
-    KToggleAction* dirShowBoth;
+    KToggleAction* dirShowBoth = nullptr;
     QPointer<QAction> dirViewToggle;
-    KToggleAction* overviewModeNormal;
-    KToggleAction* overviewModeAB;
-    KToggleAction* overviewModeAC;
-    KToggleAction* overviewModeBC;
+    KToggleAction* overviewModeNormal = nullptr;
+    KToggleAction* overviewModeAB = nullptr;
+    KToggleAction* overviewModeAC = nullptr;
+    KToggleAction* overviewModeBC = nullptr;
 
-    QMenu* m_pMergeEditorPopupMenu;
+    QMenu* m_pMergeEditorPopupMenu = nullptr;
 
     QWidget* m_pMainWidget = nullptr; // Contains vertical splitter and horiz scrollbar
     QWidget* m_pCentralWidget = nullptr;
@@ -427,14 +430,14 @@ public Q_SLOTS:
     QSplitter* m_pDiffWindowSplitter = nullptr;
 
     MergeResultWindow* m_pMergeResultWindow = nullptr;
-    WindowTitleWidget* m_pMergeResultWindowTitle;
+    WindowTitleWidget* m_pMergeResultWindowTitle = nullptr;
     static bool m_bTripleDiff;
 
     //QSplitter* m_pDirectoryMergeSplitter = nullptr;
     QDockWidget* m_pDirectoryMergeDock = nullptr;
     DirectoryMergeWindow* m_pDirectoryMergeWindow = nullptr;
     QDockWidget* m_pDirectoryMergeInfoDock = nullptr;
-    DirectoryMergeInfo* m_pDirectoryMergeInfo;
+    DirectoryMergeInfo* m_pDirectoryMergeInfo = nullptr;
     bool m_bDirCompare = false;
 
     Overview* m_pOverview = nullptr;
@@ -448,7 +451,7 @@ public Q_SLOTS:
     QSharedPointer<SourceData> m_sd3 = QSharedPointer<SourceData>::create();
 
     QString m_outputFilename;
-    bool m_bDefaultFilename;
+    bool m_bDefaultFilename = true;
 
     DiffList m_diffList12;
     DiffList m_diffList23;
@@ -459,7 +462,7 @@ public Q_SLOTS:
     ManualDiffHelpList m_manualDiffHelpList;
 
     SafeInt<QtNumberType> m_neededLines = 0;
-    int m_DTWHeight;
+    int m_DTWHeight = 0;
     bool m_bOutputModified = false;
     bool m_bFileSaved = false;
     bool m_bTimerBlock = false; // Synchronization
@@ -477,7 +480,7 @@ public Q_SLOTS:
     bool m_bAutoMode = false;
     bool m_bRecalcWordWrapPosted = false;
 
-    int m_firstD3LIdx;                 // only needed during recalcWordWrap
+    int m_firstD3LIdx = 0; // only needed during recalcWordWrap
     QPointer<QEventLoop> m_pEventLoopForPrinting;
 
     bool mRunnablesStarted = false;
