@@ -301,6 +301,8 @@ void MergeResultWindow::slotStatusMessageChanged(const QString& s)
 
 void MergeResultWindow::reset()
 {
+    m_mergeLineList.list().clear();
+
     m_pDiff3LineList = nullptr;
     m_pTotalDiffStatus = nullptr;
     m_pldA = nullptr;
@@ -750,11 +752,12 @@ int MergeResultWindow::getNumberOfUnsolvedConflicts(int* pNrOfWhiteSpaceConflict
     return nrOfUnsolvedConflicts;
 }
 
-void MergeResultWindow::showNumberOfConflicts()
+void MergeResultWindow::showNumberOfConflicts(bool showIfNone)
 {
     if(!m_pOptions->m_bShowInfoDialogs)
         return;
     int nrOfConflicts = 0;
+    int nrOfUnsolvedConflicts = getNumberOfUnsolvedConflicts();
 
     for(const MergeLine& entry: m_mergeLineList.list())
     {
@@ -762,6 +765,9 @@ void MergeResultWindow::showNumberOfConflicts()
             ++nrOfConflicts;
     }
 
+    if(!showIfNone && nrOfUnsolvedConflicts == 0)
+        return;
+
     QString totalInfo;
     if(m_pTotalDiffStatus->isBinaryEqualAB() && m_pTotalDiffStatus->isBinaryEqualAC())
         totalInfo += i18n("All input files are binary equal.");
@@ -783,8 +789,6 @@ void MergeResultWindow::showNumberOfConflicts()
             totalInfo += i18n("Files %1 and %2 have equal text.\n", i18n("B"), i18n("C"));
     }
 
-    int nrOfUnsolvedConflicts = getNumberOfUnsolvedConflicts();
-
     KMessageBox::information(this,
                              i18n("Total number of conflicts: %1\n"
                                   "Number of automatically solved conflicts: %2\n"
